# loading data and packages
rm(list=ls())
library(readxl)
library(gbm)
# library("gbm", lib.loc="C:/Users/houeq/AppData/Local/Temp/RtmpWQiNWE/downloaded_packages")
source("4_BRT/brt.functions.R") # install additional BRT functions from JAE, A working guide to boosted regression trees
library(spdep)
library(corrgram)
library(ggplot2)

packageVersion("spdep")
citation(package = "spdep")

packageVersion("gbm")
citation(package = "gbm")

brt.agr=FALSE
brt.nat=FALSE
brt.forest=FALSE

setwd("D:/2_Paper/1 P on plant prod (submitting)/Submission/Nature Communications/revision/analysis")
data=read_excel("Dataset/Data19.xlsx",sheet = 1,skip=2,col_names = T)
data2=data.frame(data$LnRR,data$Latitude,data$Longitude,data$Padditionamount,data$SoilavailableP,data$Cropspecies,
                 data$Weatheredextent,
                 data$AIvalue,data$MAT,data$MAP,data$Experimentalduration,data$SOC,data$SpH,
                 data$Ndeposition,data$Fstage,data$Parentmaterial,data$Pform,data$Ecosystem,
                 data$Forestcomposition,data$Clay,data$Nfix)
colnames(data2)=gsub("data.","",colnames(data2))

if(brt.wet){
  data.wet1=subset(data2,Ecosystem=="Wetland")
  data.wet=data.frame(data.wet1$LnRR,data.wet1$Latitude,data.wet1$Longitude,data.wet1$Padditionamount,data.wet1$Pform,
                      data.wet1$Experimentalduration,data.wet1$MAP,data.wet1$MAT)
  colnames(data.wet)=gsub("data.wet1.","",colnames(data.wet))
  names(data.wet)
  colnames(data.wet)[c(4:8)]=c("P_addition_amount","Fertilizer_type","Experimental_duration",
                                "Mean_annual_precipitation","Mean_annual_temperature")
  # BRT calculation
  # missing value is not allowed in the response
  names(data.wet)
  wet.func<-gbm.step(data=data.wet,gbm.x=c(4:8),gbm.y=1,family="gaussian",tree.complexity = 2,
                     learning.rate = 0.001, step.size = 50,max.trees = 30000,bag.fraction = 0.75)
  
  # prelimary view of model output
  wet.func$contributions   # relative contributions of each predictor
  summary(lm(wet.func$fitted~data.wet$LnRR))
  wet.writeout=data.frame(fitvalue=wet.func$fitted,
                          residual=wet.func$residuals,
                          LnRR=data.wet$LnRR)
  write.csv(wet.writeout,"4_BRT/brt_fit_wet.csv",row.names = FALSE)
  
  ggplot(wet.writeout,aes(LnRR,fitvalue))+
    geom_point()+
    geom_smooth(method="lm",se=FALSE,colour="red")+
    labs(y="Measured Ln(Response Ratio)",x="Predicted Ln(Response Ratio)")+
    theme(axis.text=element_text(size=12),
          axis.title=element_text(size=12,face="bold")) +
    theme_bw() +
    theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
  ggsave("4_BRT/model_fit_wet.tiff",
         width = 6, height =6, units = "cm", scale = 1.5, dpi = 300)
  
  # Moran'I test
  coords<-cbind(data.wet$Longitude,data.wet$Latitude)
  p_nb<-knn2nb(knearneigh(coords,k=2))
  # In knearneigh(coords, k = 2) : knearneigh: identical points found
  shoot.m<-moran.test(wet.func$residuals,nb2listw(p_nb,style = "W"))
  shoot.m
  # plots functions from the BRT model
  gbm.plot(wet.func,write.title = F,rug=T,common.scale=F,
           plot.layout = c(3,4),smooth = T,
           y.label = "Relative LnRR")
  # shoot.int<-gbm.interactions(wet.func) #assess the extent to which pairwise interaction exist in the data.
  # shoot.int # show the interaction results
  
  save.image("4_BRT/output_wet.RDA")
  load("4_BRT/output_wet.RDA")
}

if(brt.gra){
  data.gra1=subset(data2,Ecosystem=="Grass")
  data.gra=data.frame(data.gra1$LnRR,data.gra1$Latitude,data.gra1$Longitude,data.gra1$Padditionamount,data.gra1$Pform,
                      data.gra1$Experimentalduration,data.gra1$MAP,data.gra1$MAT,
                      data.gra1$SOC,data.gra1$SoilavailableP,
                      data.gra1$SpH,data.gra1$Weatheredextent)
  colnames(data.gra)=gsub("data.gra1.","",colnames(data.gra))
  names(data.gra)
  colnames(data.gra)[c(4:12)]=c("P_addition_amount","Fertilizer_type","Experimental_duration",
                                "Mean_annual_precipitation","Mean_annual_temperature",
                                "Soil_organic_C","Soil_available_P","Soil_pH","Soil_weathered_extent")
  # BRT calculation
  # missing value is not allowed in the response
  names(data.gra)
  gra.func<-gbm.step(data=data.gra,gbm.x=c(4:12),gbm.y=1,family="gaussian",tree.complexity = 2,
                     learning.rate = 0.001, step.size = 50,max.trees = 30000,bag.fraction = 0.75)
  
  # prelimary view of model output
  gra.func$contributions   # relative contributions of each predictor
  summary(lm(gra.func$fitted~data.gra$LnRR))
  gra.writeout=data.frame(fitvalue=gra.func$fitted,
                          residual=gra.func$residuals,
                          LnRR=data.gra$LnRR)
  write.csv(gra.writeout,"4_BRT/brt_fit_gra.csv",row.names = FALSE)
  
  ggplot(gra.writeout,aes(LnRR,fitvalue))+
    geom_point()+
    geom_smooth(method="lm",se=FALSE,colour="red")+
    labs(y="Measured Ln(Response Ratio)",x="Predicted Ln(Response Ratio)")+
    theme(axis.text=element_text(size=12),
          axis.title=element_text(size=12,face="bold")) +
    theme_bw() +
    theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
  ggsave("4_BRT/model_fit_gra.tiff",
         width = 6, height =6, units = "cm", scale = 1.5, dpi = 300)
  
  # Moran'I test
  coords<-cbind(data.gra$Longitude,data.gra$Latitude)
  p_nb<-knn2nb(knearneigh(coords,k=2))
  # In knearneigh(coords, k = 2) : knearneigh: identical points found
  shoot.m<-moran.test(gra.func$residuals,nb2listw(p_nb,style = "W"))
  shoot.m
  # plots functions from the BRT model
  gbm.plot(gra.func,write.title = F,rug=T,common.scale=F,
           plot.layout = c(3,4),smooth = T,
           y.label = "Relative LnRR")
  # shoot.int<-gbm.interactions(gra.func) #assess the extent to which pairwise interaction exist in the data.
  # shoot.int # show the interaction results
  
  save.image("4_BRT/output_gra.RDA")
  load("4_BRT/output_gra.RDA")
}

if(brt.for){
  data.for1=subset(data2,Ecosystem=="Forest")
  data.for=data.frame(data.for1$LnRR,data.for1$Latitude,data.for1$Longitude,data.for1$Padditionamount,data.for1$Pform,
                      data.for1$Experimentalduration,data.for1$MAP,data.for1$MAT,
                      data.for1$SOC,data.for1$SoilavailableP,
                      data.for1$SpH,data.for1$Weatheredextent)
  colnames(data.for)=gsub("data.for1.","",colnames(data.for))
  names(data.for)
  colnames(data.for)[c(4:12)]=c("P_addition_amount","Fertilizer_type","Experimental_duration",
                                "Mean_annual_precipitation","Mean_annual_temperature",
                                "Soil_organic_C","Soil_available_P","Soil_pH","Soil_weathered_extent")
  # BRT calculation
  # missing value is not allowed in the response
  names(data.for)
  for.func<-gbm.step(data=data.for,gbm.x=c(4:12),gbm.y=1,family="gaussian",tree.complexity = 2,
                     learning.rate = 0.005, step.size = 50,max.trees = 30000,bag.fraction = 0.75)
  
  # prelimary view of model output
  for.func$contributions   # relative contributions of each predictor
  summary(lm(for.func$fitted~data.for$LnRR))
  for.writeout=data.frame(fitvalue=for.func$fitted,
                          residual=for.func$residuals,
                          LnRR=data.for$LnRR)
  write.csv(for.writeout,"4_BRT/brt_fit_for.csv",row.names = FALSE)
  
  ggplot(for.writeout,aes(LnRR,fitvalue))+
    geom_point()+
    geom_smooth(method="lm",se=FALSE,colour="red")+
    labs(y="Measured Ln(Response Ratio)",x="Predicted Ln(Response Ratio)")+
    theme(axis.text=element_text(size=12),
          axis.title=element_text(size=12,face="bold")) +
    theme_bw() +
    theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
  ggsave("4_BRT/model_fit_for.tiff",
         width = 6, height =6, units = "cm", scale = 1.5, dpi = 300)
  
  # Moran'I test
  coords<-cbind(data.for$Longitude,data.for$Latitude)
  p_nb<-knn2nb(knearneigh(coords,k=2))
  # In knearneigh(coords, k = 2) : knearneigh: identical points found
  shoot.m<-moran.test(for.func$residuals,nb2listw(p_nb,style = "W"))
  shoot.m
  # plots functions from the BRT model
  gbm.plot(for.func,write.title = F,rug=T,common.scale=F,
           plot.layout = c(3,4),smooth = T,
           y.label = "Relative LnRR")
  # shoot.int<-gbm.interactions(for.func) #assess the extent to which pairwise interaction exist in the data.
  # shoot.int # show the interaction results
  
  save.image("4_BRT/output_for.RDA")
  load("4_BRT/output_for.RDA")
}

if(brt.nat){
data.nat1=subset(data2,Ecosystem!="Cropland")
data.nat=data.frame(data.nat1$LnRR,data.nat1$Latitude,data.nat1$Longitude,data.nat1$Padditionamount,data.nat1$Pform,
                    data.nat1$Experimentalduration,data.nat1$MAP,data.nat1$MAT,
                    data.nat1$Ecosystem,data.nat1$SOC,data.nat1$SoilavailableP,
                    data.nat1$SpH,data.nat1$Nfix)
colnames(data.nat)=gsub("data.nat1.","",colnames(data.nat))
data.nat$Ecosystem=droplevels(data.nat$Ecosystem)
summary(data.nat$Ecosystem)
names(data.nat)
colnames(data.nat)[c(4:13)]=c("P_addition_amount","Fertilizer_type","Experimental_duration",
                             "Mean_annual_precipitation","Mean_annual_temperature","Vegetation_type",
                             "Soil_organic_C","Soil_available_P","Soil_pH","N_fixation")
summary(data.nat)
data.nat$N_fixation[data.nat$N_fixation=="Unknown"]=NA
data.nat$N_fixation=droplevels(data.nat$N_fixation)

# BRT calculation
# missing value is not allowed in the response
names(data.nat)
nat.func<-gbm.step(data=data.nat,gbm.x=c(4:13),gbm.y=1,family="gaussian",tree.complexity = 2,
                     learning.rate = 0.005, step.size = 50,max.trees = 30000,bag.fraction = 0.75)

# prelimary view of model output
nat.func$contributions   # relative contributions of each predictor
summary(lm(data.nat$LnRR~nat.func$fitted))
nat.writeout=data.frame(fitvalue=nat.func$fitted,
                        residual=nat.func$residuals,
                        LnRR=data.nat$LnRR)
write.csv(nat.writeout,"4_BRT/brt_fit_nat.csv",row.names = FALSE)

ggplot(nat.writeout,aes(fitvalue,LnRR))+
  geom_point()+
  geom_smooth(method="lm",se=FALSE,colour="red")+
  geom_abline(slope=1,intercept = 0,colour="gray50",size=1,linetype="dashed")+
  scale_x_continuous(limits = c(-0.4,3.2))+
  scale_y_continuous(limits = c(-0.4,3.2))+
  labs(y="Measured Ln(Response Ratio)",x="Predicted Ln(Response Ratio)")+
  theme(axis.text=element_text(size=12),
        axis.title=element_text(size=12,face="bold")) +
  theme_bw() +
  theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
ggsave("4_BRT/model_fit_nat.tiff",
       width = 6, height =6, units = "cm", scale = 1.5, dpi = 300)

# Moran'I test
coords<-cbind(data.nat$Longitude,data.nat$Latitude)
p_nb<-knn2nb(knearneigh(coords,k=2))
# In knearneigh(coords, k = 2) : knearneigh: identical points found
shoot.m<-moran.test(nat.func$residuals,nb2listw(p_nb,style = "W"))
shoot.m
nat.func$contributions$var
# plots functions from the BRT model
gbm.plot(nat.func,write.title = F,rug=T,common.scale=F,
         plot.layout = c(2,3),smooth = T,
         y.label = "Relative Ln(RR)")
# shoot.int<-gbm.interactions(nat.func) #assess the extent to which pairwise interaction exist in the data.
# shoot.int # show the interaction results

save.image("4_BRT/output_nat.RDA")
load("4_BRT/output_nat.RDA")
}

if(brt.agr){
  data.agr1=subset(data2,Ecosystem=="Crop")
  summary(data.agr1)
  data.agr=data.frame(data.agr1$LnRR,data.agr1$Latitude,data.agr1$Longitude,
                      data.agr1$Padditionamount,data.agr1$Pform,
                      data.agr1$Experimentalduration,data.agr1$MAP,data.agr1$MAT,
                      data.agr1$Cropspecies,data.agr1$SOC,data.agr1$SoilavailableP,
                      data.agr1$SpH,data.agr1$Nfix)
  colnames(data.agr)=gsub("data.agr1.","",colnames(data.agr))
  names(data.agr)
  colnames(data.agr)[c(4:13)]=c("P_addition_amount","Fertilizer_type","Experimental_duration",
                                "Mean_annual_precipitation","Mean_annual_temperature","Crop_species",
                                "Soil_organic_C","Soil_available_P","Soil_pH","N_fixation")
  data.agr$N_fixation[data.agr$N_fixation=="Unknown"]=NA
  data.agr$N_fixation=droplevels(data.agr$N_fixation)
  
  agr.func<-gbm.step(data=data.agr,gbm.x=c(4:13),gbm.y=1,family="gaussian",tree.complexity = 2,
                     learning.rate = 0.005, step.size = 50,max.trees = 30000,bag.fraction = 0.75)
  
  # prelimary view of model output
  agr.func$contributions   # relative contributions of each predictor
  summary(lm(data.agr$LnRR~agr.func$fitted))
  agr.writeout=data.frame(fitvalue=agr.func$fitted,
                          residual=agr.func$residuals,
                          LnRR=data.agr$LnRR)
  write.csv(agr.writeout,"4_BRT/brt_fit_agr.csv",row.names = FALSE)
  
  ggplot(agr.writeout,aes(fitvalue,LnRR))+
    geom_point()+
    geom_smooth(method="lm",se=FALSE,colour="red")+
    geom_abline(slope=1,intercept = 0,colour="gray50",size=1,linetype="dashed")+
    scale_x_continuous(limits = c(-0.2,1.2))+
    scale_y_continuous(limits = c(-0.2,1.2))+
    labs(y="Measured Ln(Response Ratio)",x="Predicted Ln(Response Ratio)")+
    theme(axis.text=element_text(size=12),
          axis.title=element_text(size=12,face="bold")) +
    theme_bw() +
    theme(panel.grid.major = element_blank(),panel.grid.minor = element_blank())
  ggsave("4_BRT/model_fit_agr.tiff",
         width = 6, height =6, units = "cm", scale = 1.5, dpi = 300)
  
  # Moran'I test
  coords<-cbind(data.agr$Longitude,data.agr$Latitude)
  p_nb<-knn2nb(knearneigh(coords,k=2))
  # In knearneigh(coords, k = 2) : knearneigh: identical points found
  shoot.m<-moran.test(agr.func$residuals,nb2listw(p_nb,style = "W"))
  shoot.m
  agr.func$contributions$var
  # plots functions from the BRT model
  gbm.plot(agr.func, write.title = F,rug=T,common.scale=F,
           plot.layout = c(2,3),smooth = T,
           y.label = "Relative Ln(RR)")
  
  gbm.plot(agr.func,variable.no = 6,write.title = F,rug=FALSE,common.scale=F,
           plot.layout = c(1,1),smooth = T,
           y.label = "Relative LnRR")
  
  save.image("4_BRT/output_agr.RDA")
  load("4_BRT/output_agr.RDA")
  
}

