rm(list=ls())
library(readxl)
library(meta)
library(gmodels)
library(metafor)
library(altmeta)
library(reshape)
library(ggplot2)

setwd("E:/2_Paper/1 P on plant prod (submitting)/Submission/Nature Communications/revision/analysis")
multipleweight=FALSE
meta_grain=FALSE
biasest=TRUE
meantest=FALSE
measuredif=FALSE

data=read_excel("Dataset/Data19.xlsx",sheet = 1,skip=2,col_names = T)
data$Weight_var=1/(data$ProductionCSD**2/(data$ProductionCN*data$ProductionCM**2)+
                     data$ProductionPSD**2/(data$ProductionPN*data$ProductionPM**2))
data.nat=subset(data,Ecosystem!="Cropland")
data.agr=subset(data,Ecosystem=="Cropland")
data.gra=subset(data,Ecosystem=="Grassland")
data.wet=subset(data,Ecosystem=="Wetland")
data.tun=subset(data,Ecosystem=="Tundra")
data.for=subset(data,Ecosystem=="Forest")
rowval.nat=as.numeric(nrow(data.nat))

if(measuredif){
  attach(data.agr)
    metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
    summary(update(metas,byvar=Measure))
  detach(data.agr)
  
  attach(data.gra)
    metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
    summary(update(metas,byvar=Measure))
  detach(data.gra)
  
  attach(data.wet)
    metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
    summary(update(metas,byvar=MeasureS))
  detach(data.wet)
   
  attach(data.tun)
    metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
    summary(update(metas,byvar=MeasureS))
  detach(data.tun) 
    
  attach(data.for)
    metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
    summary(update(metas,byvar=Forestcomposition))
  detach(data.for) 

}

if(biasest){

attach(data.nat)
metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
summ.meta=summary(metas)
summ.meta
funnel(metas,backtransf = FALSE,lty.random = 1,xlab = "Ln(RR)")
metabias(metas)
trimfill(metas)

mr1=metareg(metas,Publicationtime)
mr1
bubble(mr1,lwd=2,max.cex = 3,xlab="Publication year",ylab="Ln(RR)",col.line="red")

metas.uni=metacont(rep(4,rowval.nat),ProductionPM,ProductionPM*0.1,rep(4,rowval.nat),ProductionCM,ProductionCM*0.1,sm="ROM")
metaacc.record.uni<-matrix(NA,rowval.nat,1000)
for(i in 1:1000){
  print(i)
  metaacc.temp=metacum(metas.uni,pooled = "fixed",sortvar = sample(Enumber))
  metaacc.record.uni[,i]=(exp(metaacc.temp$TE[1:rowval.nat])-1)*100
}
metaacc.record=data.frame(metaacc.record.uni)
colnames(metaacc.record)=seq(1,1000)
metaacc.record$AccN=seq(1,rowval.nat)
metaacc.record2=melt(metaacc.record, id= c("AccN"))
write.csv(metaacc.record2,"3_meta/quality_check/acc_meta_1000_nat_uni.csv",row.names = FALSE)

litdata.uni=data.frame(Mean=c(36.3,29.3,23.4),
                   study=c("This study","Elser et al.","Augusto et al."),
                   LowerCI=c(31.0,14.9,16.9),UpperCI=c(41.9,45.4,30.4),
                   N=c(rowval.nat,107,117))
litdata.uni$study=factor(litdata.uni$study,levels=litdata.uni$study)
ggplot() + 
  labs(x = 'Accumulated sample size',
       y = 'Effect size (%)')+
  theme_bw() +
  scale_y_continuous(limits = c(0,85))+
  geom_line(data=metaacc.record2,aes(AccN,value,group=factor(variable)),colour="gray50")+
  geom_point(data=litdata.uni,aes(N,Mean,colour=study),size=2)+
  geom_errorbar(data=litdata.uni,aes(x=N,ymin=LowerCI, ymax=UpperCI,colour=study), width=.5,
                position=position_dodge(0.05))+
  theme(text=element_text(family="Times New Roman", size=10),
        legend.text=element_text(size=8),
        legend.position = c(0.65,0.8),
        legend.key.size = unit(1.0, 'lines')) +
  guides(col=guide_legend(title="Study"))
ggsave("3_meta/quality_check/acc_meta_nat_1000_uniform.tiff",
       width = 12, height =8, units = "cm", scale = 1, dpi = 300)


metaacc.record<-matrix(NA,rowval.nat,1000)
for(i in 1:1000){
  print(i)
metaacc.temp=metacum(metas,pooled = "random",sortvar = sample(Enumber))
metaacc.record[,i]=(exp(metaacc.temp$TE[1:rowval.nat])-1)*100
}
metaacc.record=data.frame(metaacc.record)
colnames(metaacc.record)=seq(1,1000)
metaacc.record$AccN=seq(1,rowval.nat)
metaacc.record2=melt(metaacc.record, id= c("AccN"))
write.csv(metaacc.record2,"3_meta/quality_check/acc_meta_1000_nat_invvar.csv",row.names = FALSE)
metaacc.record2 = read.csv("3_meta/quality_check/acc_meta_1000_nat_invvar.csv")
litdata=data.frame(Mean=c(34.9,17.77),
                   study=c("This study","Yue et al."),
                   LowerCI=c(30.0,11.1),UpperCI=c(40.1,24.8),
                   N=c(rowval.nat,60))
# litdata
ggplot() + 
  labs(x = 'Accumulated sample size',
       y = 'Effect size (%)')+
  theme_bw() +
  scale_y_continuous(limits = c(0,85))+
  geom_line(data=metaacc.record2,aes(AccN,value,group=factor(variable)),colour="gray50")+
  geom_point(data=litdata,aes(N,Mean,colour=study),size=2)+
  geom_errorbar(data=litdata,aes(x=N,ymin=LowerCI, ymax=UpperCI,colour=study), width=.5,
                position=position_dodge(0.05))+
  theme(text=element_text(family="Times New Roman", size=10),
        legend.text=element_text(size=8),
        legend.position = c(0.65,0.85),
        legend.key.size = unit(1.0, 'lines')) +
  guides(col=guide_legend(title="Study"))
ggsave("3_meta/quality_check/acc_meta_nat_1000.tiff",
       width = 12, height =8, units = "cm", scale = 1, dpi = 300)

metaoneout=metainf(metas,pooled = "random")
maxi=max((exp(metaoneout$upper)-1)*100,na.rm = TRUE)
mini=min((exp(metaoneout$lower)-1)*100,na.rm = TRUE)
jpeg('3_meta/quality_check/one_out_meta_nat.jpg',width = 1000, height = 800, units = "px", pointsize = 30,
     quality = 1200,bg = "white")
plot((exp(metaoneout$TE)-1)*100,ylim=c(mini*0.95,maxi*1.05),xlab="Number of test",ylab="Effect size (%)")
points((exp(metaoneout$upper)-1)*100,type="l",col="red")
points((exp(metaoneout$lower)-1)*100,type="l",col="green")
dev.off()

mataoneout.out=data.frame(Average=(exp(metaoneout$TE)-1)*100,
                          UpperCI=(exp(metaoneout$upper)-1)*100,
                          LowerCI=(exp(metaoneout$lower)-1)*100)
write.csv(mataoneout.out,"3_meta/quality_check/one_out_meta_nat.csv",row.names = FALSE)

detach(data.nat)

attach(data.agr)
metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
summ.meta=summary(metas)
summ.meta
funnel(metas,backtransf = FALSE,lty.random = 1,xlab = "Ln(RR)")
metabias(metas)
trimfill(metas)

mr1=metareg(metas,Publicationtime)
mr1
bubble(mr1,max.cex = 3,xlab="Publication year",ylab="Ln(RR)",regline = FALSE)

metaacc.record<-matrix(NA,216,1000)
for(i in 1:1000){
  print(i)
  metaacc.temp=metacum(metas,pooled = "random",sortvar = sample(Enumber))
  metaacc.record[,i]=(exp(metaacc.temp$TE[1:216])-1)*100
}
metaacc.record=data.frame(metaacc.record)
colnames(metaacc.record)=seq(1,1000)
metaacc.record$AccN=seq(1,216)
metaacc.record2=melt(metaacc.record, id= c("AccN"))
write.csv(metaacc.record2,"3_meta/quality_check/acc_meta_1000_agr.csv",row.names = FALSE)

ggplot() + 
  labs(x = 'Accumulated sample size',
       y = 'Effect size (%)')+
  theme_bw() +
  scale_y_continuous(limits = c(-20,50))+
  geom_line(data=metaacc.record2,aes(AccN,value,group=factor(variable)),colour="gray50")+
  theme(text=element_text(family="Times New Roman", size=10)) +
  guides(col=guide_legend(title="Mean"))
ggsave("3_meta/quality_check/acc_meta_agr_1000.tiff",
       width = 12, height =8, units = "cm", scale = 1, dpi = 300)

metaoneout=metainf(metas,pooled = "random")
maxi=max((exp(metaoneout$upper)-1)*100,na.rm = TRUE)
mini=min((exp(metaoneout$lower)-1)*100,na.rm = TRUE)
jpeg('3_meta/quality_check/one_out_meta_agr.jpg',width = 1000, height = 800, units = "px", pointsize = 30,
     quality = 1200,bg = "white")
plot((exp(metaoneout$TE)-1)*100,ylim=c(mini*0.95,maxi*1.05),xlab="Number of test",ylab="Effect size (%)")
points((exp(metaoneout$upper)-1)*100,type="l",col="red")
points((exp(metaoneout$lower)-1)*100,type="l",col="green")
dev.off()

mataoneout.out=data.frame(Average=(exp(metaoneout$TE)-1)*100,
                          UpperCI=(exp(metaoneout$upper)-1)*100,
                          LowerCI=(exp(metaoneout$lower)-1)*100)
write.csv(mataoneout.out,"3_meta/quality_check/one_out_meta_agr.csv",row.names = FALSE)

detach(data.agr)

}


if(meantest){
  datamean=read_excel("Dataset/Data_based_on_treatment_mean.xlsx",sheet = 1,skip=1,col_names = T)
  highpdata=subset(datamean,HighPlevel=="Y"&Finalno>0)
  highpdata2=data.frame(Group=highpdata$Group,LnRR_highP=highpdata$LnRR,Vege=highpdata$Ecosystem)
  datamean2=data.frame(Group = tapply(datamean$Group, datamean$Group, mean),
                      LnRR_mean = tapply(datamean$LnRR, list(datamean$Group), mean,na.rm=TRUE))
  mean3=merge(highpdata2,datamean2,by=c("Group"),all.x=TRUE)
  mean3.nat=subset(mean3,Vege!="Crop")
  mean3.agr=subset(mean3,Vege=="Crop")
  summary(mean3.nat)
  summary(mean3.agr)
  exp(0.151)
  exp(0.300)
}

if(multipleweight){
  
  exp(ci(data.nat$LnRR*(sqrt(data.nat$Weight_var)/mean(sqrt(data.nat$Weight_var),na.rm=T)),na.rm = T))
  exp(ci(data.nat$LnRR))
  data.nat$WeightN=data.nat$ProductionCN*data.nat$ProductionPN/(data.nat$ProductionCN+data.nat$ProductionPN)
  summary(data.nat$WeightN)
  exp(ci(data.nat$LnRR*(data.nat$WeightN/mean(data.nat$WeightN))))
  exp(ci(data.nat$LnRR*(data.nat$Padditionamount/mean(data.nat$Padditionamount,na.rm=T)),na.rm = T))
  exp(ci(data.nat$LnRR*(data.nat$Experimentalduration/mean(data.nat$Experimentalduration))))
  ci(data.nat$ProductionPM/data.nat$ProductionCM*(sqrt(data.nat$Weight_var)/mean(sqrt(data.nat$Weight_var),na.rm=T)),na.rm = T)
  
  exp(ci(data.agr$LnRR*(sqrt(data.agr$Weight_var)/mean(sqrt(data.agr$Weight_var),na.rm=T)),na.rm = T))
  exp(ci(data.agr$LnRR))
  data.agr$WeightN=data.agr$ProductionCN*data.agr$ProductionPN/(data.agr$ProductionCN+data.agr$ProductionPN)
  exp(ci(data.agr$LnRR*(data.agr$WeightN/mean(data.agr$WeightN))))
  exp(ci(data.agr$LnRR*(data.agr$Experimentalduration/mean(data.agr$Experimentalduration))))
  exp(ci(data.agr$LnRR*(data.agr$Padditionamount/mean(data.agr$Padditionamount,na.rm=T)),na.rm = T))
  ci(data.agr$ProductionPM/data.agr$ProductionCM*(sqrt(data.agr$Weight_var)/mean(sqrt(data.agr$Weight_var),na.rm=T)),na.rm = T)
  
  }

summ.nat=data.frame(Order=seq(1,100),Group=NA,Mean_nat=NA,LowerCI_nat=NA,UpperCI_nat=NA,P_nat=NA,N_nat=NA)
attach(data.nat)
metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
summ.meta=summary(metas)
summ.meta

summ.nat$Group[1]="Overall"
summ.nat$Mean_nat[1]=(exp(summ.meta$random$TE)-1)*100
summ.nat$LowerCI_nat[1]=(exp(summ.meta$random$lower)-1)*100
summ.nat$UpperCI_nat[1]=(exp(summ.meta$random$upper)-1)*100
summ.nat$P_nat[1]=summ.meta$random$p
summ.nat$N_nat[1]=summ.meta$k

summ.nat.continent=summary(update(metas,byvar=Continent))
summ.nat.continent
summ.nat$Group[2:7]=strsplit(summ.nat.continent$bylevs," ")[c(3,1,2,4,6,5)]
summ.nat$Mean_nat[2:7]=(exp(summ.nat.continent$within.random$TE[c(3,1,2,4,6,5)])-1)*100
summ.nat$LowerCI_nat[2:7]=(exp(summ.nat.continent$within.random$lower[c(3,1,2,4,6,5)])-1)*100
summ.nat$UpperCI_nat[2:7]=(exp(summ.nat.continent$within.random$upper[c(3,1,2,4,6,5)])-1)*100
summ.nat$P_nat[2:7]=summ.nat.continent$within.random$p[c(3,1,2,4,6,5)]
summ.nat$N_nat[2:7]=summ.nat.continent$k.w[c(3,1,2,4,6,5)]

summ.nat.region=summary(update(metas,byvar=Region))
summ.nat$Group[8:11]=strsplit(summ.nat.region$bylevs," ")[c(3,2,1,4)]
summ.nat$Mean_nat[8:11]=(exp(summ.nat.region$within.random$TE[c(3,2,1,4)])-1)*100
summ.nat$LowerCI_nat[8:11]=(exp(summ.nat.region$within.random$lower[c(3,2,1,4)])-1)*100
summ.nat$UpperCI_nat[8:11]=(exp(summ.nat.region$within.random$upper[c(3,2,1,4)])-1)*100
summ.nat$P_nat[8:11]=summ.nat.region$within.random$p[c(3,2,1,4)]
summ.nat$N_nat[8:11]=summ.nat.region$k.w[c(3,2,1,4)]

summ.nat.altitude=summary(update(metas,byvar=Altitudegroup))
summ.nat$Group[12:13]=strsplit(summ.nat.altitude$bylevs,"  ")[c(2,1)]
summ.nat$Mean_nat[12:13]=(exp(summ.nat.altitude$within.random$TE[c(2,1)])-1)*100
summ.nat$LowerCI_nat[12:13]=(exp(summ.nat.altitude$within.random$lower[c(2,1)])-1)*100
summ.nat$UpperCI_nat[12:13]=(exp(summ.nat.altitude$within.random$upper[c(2,1)])-1)*100
summ.nat$P_nat[12:13]=summ.nat.altitude$within.random$p[c(2,1)]
summ.nat$N_nat[12:13]=summ.nat.altitude$k.w[c(2,1)]

summ.nat.aridity=summary(update(metas,byvar=Ariditygroup))
summ.nat$Group[14:18]=strsplit(summ.nat.aridity$bylevs,"  ")[c(3,2,1,4,5)]
summ.nat$Mean_nat[14:18]=(exp(summ.nat.aridity$within.random$TE[c(3,2,1,4,5)])-1)*100
summ.nat$LowerCI_nat[14:18]=(exp(summ.nat.aridity$within.random$lower[c(3,2,1,4,5)])-1)*100
summ.nat$UpperCI_nat[14:18]=(exp(summ.nat.aridity$within.random$upper[c(3,2,1,4,5)])-1)*100
summ.nat$P_nat[14:18]=summ.nat.aridity$within.random$p[c(3,2,1,4,5)]
summ.nat$N_nat[14:18]=summ.nat.aridity$k.w[c(3,2,1,4,5)]

summ.nat.pamount=summary(update(metas,byvar=Pamountgroup))
summ.nat$Group[19:22]=strsplit(summ.nat.pamount$bylevs,"  ")[c(4,1,2,3)]
summ.nat$Mean_nat[19:22]=(exp(summ.nat.pamount$within.random$TE[c(4,1,2,3)])-1)*100
summ.nat$LowerCI_nat[19:22]=(exp(summ.nat.pamount$within.random$lower[c(4,1,2,3)])-1)*100
summ.nat$UpperCI_nat[19:22]=(exp(summ.nat.pamount$within.random$upper[c(4,1,2,3)])-1)*100
summ.nat$P_nat[19:22]=summ.nat.pamount$within.random$p[c(4,1,2,3)]
summ.nat$N_nat[19:22]=summ.nat.pamount$k.w[c(4,1,2,3)]

summ.nat.duration=summary(update(metas,byvar=Durationgroup))
summ.nat$Group[23:26]=strsplit(summ.nat.duration$bylevs,"  ")[c(4,3,1,2)]
summ.nat$Mean_nat[23:26]=(exp(summ.nat.duration$within.random$TE[c(4,3,1,2)])-1)*100
summ.nat$LowerCI_nat[23:26]=(exp(summ.nat.duration$within.random$lower[c(4,3,1,2)])-1)*100
summ.nat$UpperCI_nat[23:26]=(exp(summ.nat.duration$within.random$upper[c(4,3,1,2)])-1)*100
summ.nat$P_nat[23:26]=summ.nat.duration$within.random$p[c(4,3,1,2)]
summ.nat$N_nat[23:26]=summ.nat.duration$k.w[c(4,3,1,2)]

summ.nat.pform=summary(update(metas,byvar=Pform))
summ.nat$Group[27:29]=strsplit(summ.nat.pform$bylevs,"  ")[c(3,2,1)]
summ.nat$Mean_nat[27:29]=(exp(summ.nat.pform$within.random$TE[c(3,2,1)])-1)*100
summ.nat$LowerCI_nat[27:29]=(exp(summ.nat.pform$within.random$lower[c(3,2,1)])-1)*100
summ.nat$UpperCI_nat[27:29]=(exp(summ.nat.pform$within.random$upper[c(3,2,1)])-1)*100
summ.nat$P_nat[27:29]=summ.nat.pform$within.random$p[c(3,2,1)]
summ.nat$N_nat[27:29]=summ.nat.pform$k.w[c(3,2,1)]

summ.nat.nfix=summary(update(metas,byvar=Nfix))
summ.nat$Group[30:32]=strsplit(summ.nat.nfix$bylevs,"  ")[c(1,3,2)]
summ.nat$Mean_nat[30:32]=(exp(summ.nat.nfix$within.random$TE[c(1,3,2)])-1)*100
summ.nat$LowerCI_nat[30:32]=(exp(summ.nat.nfix$within.random$lower[c(1,3,2)])-1)*100
summ.nat$UpperCI_nat[30:32]=(exp(summ.nat.nfix$within.random$upper[c(1,3,2)])-1)*100
summ.nat$P_nat[30:32]=summ.nat.nfix$within.random$p[c(1,3,2)]
summ.nat$N_nat[30:32]=summ.nat.nfix$k.w[c(1,3,2)]

summ.nat.fage=summary(update(metas,byvar=Forestage))
summ.nat$Group[33:36]=strsplit(summ.nat.fage$bylevs,"  ")[c(4,2,3,5)]
summ.nat$Mean_nat[33:36]=(exp(summ.nat.fage$within.random$TE[c(4,2,3,5)])-1)*100
summ.nat$LowerCI_nat[33:36]=(exp(summ.nat.fage$within.random$lower[c(4,2,3,5)])-1)*100
summ.nat$UpperCI_nat[33:36]=(exp(summ.nat.fage$within.random$upper[c(4,2,3,5)])-1)*100
summ.nat$P_nat[33:36]=summ.nat.fage$within.random$p[c(4,2,3,5)]
summ.nat$N_nat[33:36]=summ.nat.fage$k.w[c(4,2,3,5)]

summ.nat.wextent=summary(update(metas,byvar=Weatheredextent))
summ.nat$Group[37:39]=strsplit(summ.nat.wextent$bylevs,"  ")[c(2,4,3)]
summ.nat$Mean_nat[37:39]=(exp(summ.nat.wextent$within.random$TE[c(2,4,3)])-1)*100
summ.nat$LowerCI_nat[37:39]=(exp(summ.nat.wextent$within.random$lower[c(2,4,3)])-1)*100
summ.nat$UpperCI_nat[37:39]=(exp(summ.nat.wextent$within.random$upper[c(2,4,3)])-1)*100
summ.nat$P_nat[37:39]=summ.nat.wextent$within.random$p[c(2,4,3)]
summ.nat$N_nat[37:39]=summ.nat.wextent$k.w[c(2,4,3)]

summ.nat.ecosystem=summary(update(metas,byvar=Ecosystem))
summ.nat$Group[40:43]=strsplit(summ.nat.ecosystem$bylevs,"  ")[c(2,1,4,3)]
summ.nat$Mean_nat[40:43]=(exp(summ.nat.ecosystem$within.random$TE[c(2,1,4,3)])-1)*100
summ.nat$LowerCI_nat[40:43]=(exp(summ.nat.ecosystem$within.random$lower[c(2,1,4,3)])-1)*100
summ.nat$UpperCI_nat[40:43]=(exp(summ.nat.ecosystem$within.random$upper[c(2,1,4,3)])-1)*100
summ.nat$P_nat[40:43]=summ.nat.ecosystem$within.random$p[c(2,1,4,3)]
summ.nat$N_nat[40:43]=summ.nat.ecosystem$k.w[c(2,1,4,3)]

summ.nat.soiltype=summary(update(metas,byvar=Soiltype))
summ.nat$Group[44:54]=strsplit(summ.nat.soiltype$bylevs,"  ")[c(8,3,7,6,5,4,9,10,2,11)]
summ.nat$Mean_nat[44:54]=(exp(summ.nat.soiltype$within.random$TE[c(8,3,7,6,5,4,9,10,2,11)])-1)*100
summ.nat$LowerCI_nat[44:54]=(exp(summ.nat.soiltype$within.random$lower[c(8,3,7,6,5,4,9,10,2,11)])-1)*100
summ.nat$UpperCI_nat[44:54]=(exp(summ.nat.soiltype$within.random$upper[c(8,3,7,6,5,4,9,10,2,11)])-1)*100
summ.nat$P_nat[44:54]=summ.nat.soiltype$within.random$p[c(8,3,7,6,5,4,9,10,2,11)]
summ.nat$N_nat[44:54]=summ.nat.soiltype$k.w[c(8,3,7,6,5,4,9,10,2,11)]

summ.nat.parmat=summary(update(metas,byvar=Parentmaterial))
summ.nat$Group[55:58]=strsplit(summ.nat.parmat$bylevs,"  ")[c(4,3,2,5)]
summ.nat$Mean_nat[55:58]=(exp(summ.nat.parmat$within.random$TE[c(4,3,2,5)])-1)*100
summ.nat$LowerCI_nat[55:58]=(exp(summ.nat.parmat$within.random$lower[c(4,3,2,5)])-1)*100
summ.nat$UpperCI_nat[55:58]=(exp(summ.nat.parmat$within.random$upper[c(4,3,2,5)])-1)*100
summ.nat$P_nat[55:58]=summ.nat.parmat$within.random$p[c(4,3,2,5)]
summ.nat$N_nat[55:58]=summ.nat.parmat$k.w[c(4,3,2,5)]

summary(update(metas,byvar=Forestcomposition))

detach(data.nat)



summ.agr=data.frame(Group=rep(NA,100),Mean_agr=NA,LowerCI_agr=NA,UpperCI_agr=NA,P_agr=NA,N_agr=NA)
attach(data.agr)
metas=metacont(ProductionPN,ProductionPM,ProductionPSD,ProductionCN,ProductionCM,ProductionCSD,sm="ROM")
metas
summ.meta=summary(metas)
summ.agr$Group[1]="Overall"
summ.agr$Mean_agr[1]=(exp(summ.meta$random$TE)-1)*100
summ.agr$LowerCI_agr[1]=(exp(summ.meta$random$lower)-1)*100
summ.agr$UpperCI_agr[1]=(exp(summ.meta$random$upper)-1)*100
summ.agr$P_agr[1]=summ.meta$random$p
summ.agr$N_agr[1]=summ.meta$k

summ.agr.continent=summary(update(metas,byvar=Continent))
summ.agr$Group[2:7]=strsplit(summ.agr.continent$bylevs," ")[c(3,1,2,4,6,5)]
summ.agr$Mean_agr[2:7]=(exp(summ.agr.continent$within.random$TE[c(3,1,2,4,6,5)])-1)*100
summ.agr$LowerCI_agr[2:7]=(exp(summ.agr.continent$within.random$lower[c(3,1,2,4,6,5)])-1)*100
summ.agr$UpperCI_agr[2:7]=(exp(summ.agr.continent$within.random$upper[c(3,1,2,4,6,5)])-1)*100
summ.agr$P_agr[2:7]=summ.agr.continent$within.random$p[c(3,1,2,4,6,5)]
summ.agr$N_agr[2:7]=summ.agr.continent$k.w[c(3,1,2,4,6,5)]

summ.agr.region=summary(update(metas,byvar=Region))
summ.agr$Group[8:11]=strsplit(summ.agr.region$bylevs," ")[c(3,2,1,4)]
summ.agr$Mean_agr[8:11]=(exp(summ.agr.region$within.random$TE[c(3,2,1,4)])-1)*100
summ.agr$LowerCI_agr[8:11]=(exp(summ.agr.region$within.random$lower[c(3,2,1,4)])-1)*100
summ.agr$UpperCI_agr[8:11]=(exp(summ.agr.region$within.random$upper[c(3,2,1,4)])-1)*100
summ.agr$P_agr[8:11]=summ.agr.region$within.random$p[c(3,2,1,4)]
summ.agr$N_agr[8:11]=summ.agr.region$k.w[c(3,2,1,4)]

summ.agr.altitude=summary(update(metas,byvar=Altitudegroup))
summ.agr$Group[12:13]=strsplit(summ.agr.altitude$bylevs,"  ")[c(2,1)]
summ.agr$Mean_agr[12:13]=(exp(summ.agr.altitude$within.random$TE[c(2,1)])-1)*100
summ.agr$LowerCI_agr[12:13]=(exp(summ.agr.altitude$within.random$lower[c(2,1)])-1)*100
summ.agr$UpperCI_agr[12:13]=(exp(summ.agr.altitude$within.random$upper[c(2,1)])-1)*100
summ.agr$P_agr[12:13]=summ.agr.altitude$within.random$p[c(2,1)]
summ.agr$N_agr[12:13]=summ.agr.altitude$k.w[c(2,1)]

summ.agr.aridity=summary(update(metas,byvar=Ariditygroup))
summ.agr$Group[14:18]=strsplit(summ.agr.aridity$bylevs,"  ")[c(3,2,1,4,5)]
summ.agr$Mean_agr[14:18]=(exp(summ.agr.aridity$within.random$TE[c(3,2,1,4,5)])-1)*100
summ.agr$LowerCI_agr[14:18]=(exp(summ.agr.aridity$within.random$lower[c(3,2,1,4,5)])-1)*100
summ.agr$UpperCI_agr[14:18]=(exp(summ.agr.aridity$within.random$upper[c(3,2,1,4,5)])-1)*100
summ.agr$P_agr[14:18]=summ.agr.aridity$within.random$p[c(3,2,1,4,5)]
summ.agr$N_agr[14:18]=summ.agr.aridity$k.w[c(3,2,1,4,5)]

summ.agr.pamount=summary(update(metas,byvar=Pamountgroup))
summ.agr$Group[19:22]=strsplit(summ.agr.pamount$bylevs,"  ")[c(4,1,2,3)]
summ.agr$Mean_agr[19:22]=(exp(summ.agr.pamount$within.random$TE[c(4,1,2,3)])-1)*100
summ.agr$LowerCI_agr[19:22]=(exp(summ.agr.pamount$within.random$lower[c(4,1,2,3)])-1)*100
summ.agr$UpperCI_agr[19:22]=(exp(summ.agr.pamount$within.random$upper[c(4,1,2,3)])-1)*100
summ.agr$P_agr[19:22]=summ.agr.pamount$within.random$p[c(4,1,2,3)]
summ.agr$N_agr[19:22]=summ.agr.pamount$k.w[c(4,1,2,3)]

summ.agr.duration=summary(update(metas,byvar=Durationgroup))
summ.agr$Group[23:26]=strsplit(summ.agr.duration$bylevs,"  ")[c(1,2,3,4)]
summ.agr$Mean_agr[23:26]=(exp(summ.agr.duration$within.random$TE[c(1,2,3,4)])-1)*100
summ.agr$LowerCI_agr[23:26]=(exp(summ.agr.duration$within.random$lower[c(1,2,3,4)])-1)*100
summ.agr$UpperCI_agr[23:26]=(exp(summ.agr.duration$within.random$upper[c(1,2,3,4)])-1)*100
summ.agr$P_agr[23:26]=summ.agr.duration$within.random$p[c(1,2,3,4)]
summ.agr$N_agr[23:26]=summ.agr.duration$k.w[c(1,2,3,4)]

summ.agr.pform=summary(update(metas,byvar=Pform))
summ.agr$Group[27:29]=strsplit(summ.agr.pform$bylevs,"  ")[c(3,2,1)]
summ.agr$Mean_agr[27:29]=(exp(summ.agr.pform$within.random$TE[c(3,2,1)])-1)*100
summ.agr$LowerCI_agr[27:29]=(exp(summ.agr.pform$within.random$lower[c(3,2,1)])-1)*100
summ.agr$UpperCI_agr[27:29]=(exp(summ.agr.pform$within.random$upper[c(3,2,1)])-1)*100
summ.agr$P_agr[27:29]=summ.agr.pform$within.random$p[c(3,2,1)]
summ.agr$N_agr[27:29]=summ.agr.pform$k.w[c(3,2,1)]

summ.agr.nfix=summary(update(metas,byvar=Nfix))
summ.agr$Group[30:32]=strsplit(summ.agr.nfix$bylevs,"  ")[c(1,3,2)]
summ.agr$Mean_agr[30:32]=(exp(summ.agr.nfix$within.random$TE[c(1,3,2)])-1)*100
summ.agr$LowerCI_agr[30:32]=(exp(summ.agr.nfix$within.random$lower[c(1,3,2)])-1)*100
summ.agr$UpperCI_agr[30:32]=(exp(summ.agr.nfix$within.random$upper[c(1,3,2)])-1)*100
summ.agr$P_agr[30:32]=summ.agr.nfix$within.random$p[c(1,3,2)]
summ.agr$N_agr[30:32]=summ.agr.nfix$k.w[c(1,3,2)]

summ.agr.wextent=summary(update(metas,byvar=Weatheredextent))
# summ.agr.wextent$bylevs
summ.agr$Group[37:39]=strsplit(summ.agr.wextent$bylevs,"  ")[c(1:3)]
summ.agr$Mean_agr[37:39]=(exp(summ.agr.wextent$within.random$TE[c(1:3)])-1)*100
summ.agr$LowerCI_agr[37:39]=(exp(summ.agr.wextent$within.random$lower[c(1:3)])-1)*100
summ.agr$UpperCI_agr[37:39]=(exp(summ.agr.wextent$within.random$upper[c(1:3)])-1)*100
summ.agr$P_agr[37:39]=summ.agr.wextent$within.random$p[c(2,4,3)]
summ.agr$N_agr[37:39]=summ.agr.wextent$k.w[c(2,4,3)]

summ.agr.cspecies=summary(update(metas,byvar=Cropspecies))
summ.agr$Group[40:48]=strsplit(summ.agr.cspecies$bylevs,"  ")[c(1,3:10)]
summ.agr$Mean_agr[40:48]=(exp(summ.agr.cspecies$within.random$TE[c(1,3:10)])-1)*100
summ.agr$LowerCI_agr[40:48]=(exp(summ.agr.cspecies$within.random$lower[c(1,3:10)])-1)*100
summ.agr$UpperCI_agr[40:48]=(exp(summ.agr.cspecies$within.random$upper[c(1,3:10)])-1)*100
summ.agr$P_agr[40:48]=summ.agr.cspecies$within.random$p[c(1,3:10)]
summ.agr$N_agr[40:48]=summ.agr.cspecies$k.w[c(1,3:10)]

summ.agr.soiltype=summary(update(metas,byvar=Soiltype))
summ.agr$Group[49:57]=strsplit(summ.agr.soiltype$bylevs,"  ")[c(1:7,9,10)]
summ.agr$Mean_agr[49:57]=(exp(summ.agr.soiltype$within.random$TE[c(1:7,9,10)])-1)*100
summ.agr$LowerCI_agr[49:57]=(exp(summ.agr.soiltype$within.random$lower[c(1:7,9,10)])-1)*100
summ.agr$UpperCI_agr[49:57]=(exp(summ.agr.soiltype$within.random$upper[c(1:7,9,10)])-1)*100
summ.agr$P_agr[49:57]=summ.agr.soiltype$within.random$p[c(1:7,9,10)]
summ.agr$N_agr[49:57]=summ.agr.soiltype$k.w[c(1:7,9,10)]

summ.agr.parmat=summary(update(metas,byvar=Parentmaterial))
summ.agr$Group[58:60]=strsplit(summ.agr.parmat$bylevs,"  ")[c(2:4)]
summ.agr$Mean_agr[58:60]=(exp(summ.agr.parmat$within.random$TE[c(2:4)])-1)*100
summ.agr$LowerCI_agr[58:60]=(exp(summ.agr.parmat$within.random$lower[c(2:4)])-1)*100
summ.agr$UpperCI_agr[58:60]=(exp(summ.agr.parmat$within.random$upper[c(2:4)])-1)*100
summ.agr$P_agr[58:60]=summ.agr.parmat$within.random$p[c(2:4)]
summ.agr$N_agr[58:60]=summ.agr.parmat$k.w[c(2:4)]

detach(data.agr)

summ.nat$Group=as.character(summ.nat$Group)
summ.agr$Group=as.character(summ.agr$Group)
summ.nat=summ.nat[complete.cases(summ.nat$Group),]
summ.agr=summ.agr[complete.cases(summ.agr$Group),]
summ.all=merge(summ.nat,summ.agr,by=c("Group"),all=TRUE)
write.csv(summ.nat,"3_meta/meta_output_nat.csv")
write.csv(summ.agr,"3_meta/meta_output_agr.csv")


if(meta_grain){
  data.agr4grain=data.frame(data.agr$Enumber,data.agr$Shoot_mean_con,data.agr$Shoot_se_con,data.agr$Shoot_n_con,
                            data.agr$Shoot_mean_padd,data.agr$Shoot_se_padd,data.agr$Shoot_n_padd,
                            data.agr$Grain_mean_con,data.agr$Grain_se_con,data.agr$Grain_n_con,
                            data.agr$Grain_mean_padd,data.agr$Grain_se_padd,data.agr$Grain_n_padd)
  colnames(data.agr4grain)=gsub("data.agr.","",colnames(data.agr4grain))
  data.grain=read_excel("5_Summary/grain_shoot/data_out.xlsx",sheet = 1,col_names = T)
  data.grain2=merge(data.grain,data.agr4grain,by.by=c("Enumber"),all.x=TRUE)
  data.grain2$Shoot_SD_con=data.grain2$Shoot_se_con*sqrt(data.grain2$Shoot_n_con)
  data.grain2$Shoot_SD_padd=data.grain2$Shoot_se_padd*sqrt(data.grain2$Shoot_n_padd)
  data.grain2$Grain_SD_con=data.grain2$Grain_se_con*sqrt(data.grain2$Grain_n_con)
  data.grain2$Grain_SD_padd=data.grain2$Grain_se_padd*sqrt(data.grain2$Grain_n_padd)
  
  attach(data.grain2)
  meta_shoot=metacont(Shoot_n_padd,Shoot_mean_padd,Shoot_SD_padd,Shoot_n_con,Shoot_mean_con,Shoot_SD_con,sm="ROM")
  meta_grain=metacont(Grain_n_padd,Grain_mean_padd,Grain_SD_padd,Grain_n_con,Grain_mean_con,Grain_SD_con,sm="ROM")
  detach(data.grain2)
}


